## Copyright (C) 2000, 2001, 2002  SWsoft
## All rights reserved.
## Abstract base class for all plugin configurations
package HSPC::MT::PluginConfig;

use strict;

use HSPC::DataRequest;
#use HSPC::MT::Core;
use HSPC::MT::Core::Constants;
#use HSPC::MT::CM::ResellerConfig;
use HSPC::MT::PluginTools qw(set_request_data);
use HSPC::PluginToolkit::General qw(throw_exception);
use Storable qw(freeze thaw);

use vars qw(@ISA);
@ISA = qw( HSPC::MT::Abstract);

use constant CLASS_INFO => {
    props => {
		'id'           => {col => 'id',           table => 'plugin', key => 'AUTO'},
		'template_id'  => {col => 'template_id',  table => 'plugin', type => 'char'},
		'vendor_id'    => {col => 'vendor_id',    table => 'plugin', type => 'int'},
		'is_active'    => {col => 'is_active',    table => 'plugin', type => 'int'},
		'plugin_type'  => {col => 'plugin_type',  table => 'plugin', type => 'char'},
		'name'         => {col => 'name',         table => 'plugin', type => 'char'},
		'config_data'  => {col => 'config_data',  table => 'plugin', type => 'char'},
	},
	tables => {
        'plugin'=>{name=>'plugin', read_only=>0},
	}
};

## find template for plugin
sub find_mt_template{
	my $self = shift;
	my %h = (
		plugin_type => undef,
		template_id => undef,
		@_
	);
	
	my $plugin_type = $h{plugin_type}
		|| $self->plugin_type;
	
	my $template_id = $h{template_id}
		|| $self->template_id;

	my $template = 'HSPC::MT::Plugin::'
		. $plugin_type
		. '::'
		. $template_id;
	
	eval "use $template";

	if ( $self->check_template( template => $template ) ) {
		return $template;
	}

	return undef;
}

## find presentation module for plugin
sub find_presentation_template{
	my $self = shift;
	my %h = (
		plugin_type => undef,
		template_id => undef,
		@_
	);

	my $plugin_type = $h{plugin_type}
		|| $self->plugin_type;
	
	my $template_id = $h{template_id}
		|| $self->template_id;

	my $template = 'HSPC::Plugin::'
		. $plugin_type
		. '::'
		. $template_id;	
	
	eval "use $template";

	if ( $self->check_template( template => $template ) ) {
		return $template;
	}

	return undef;
}

## check existence template in system
sub check_template {
	my $self = shift;
	my %h = (
		template => undef,
		@_
	);
	
	my $template = $h{template};

	$template =~ s/::/\//g;
	$template .= ".pm";

	if ( grep { $_ eq $template } keys (%INC) ) {
		return 1;
	}
	return undef;
}

## Find templates installed in system
## for $plugin_type plugins
## Return array of hashes - template_id => module name
sub find_templates{
	my $class = shift;
	my %h = (
		plugin_type      => undef,
		vendor_id        => undef,
		force_permission => undef,
		@_
	);

	my $plugin_type      = $h{plugin_type};
	my $vendor_id        = $h{vendor_id};
	my $force_permission = $h{force_permission};

	throw_exception(
		type        => 'error',
		log_message => 'plugin_type is a mandatory parameter'
	) unless $plugin_type;

	if ($h{vendor_id} == SW_HSP_ID || $force_permission) {
		use HSPC::WebDB;
		use File::Basename;

		my $plugins_dir = dirname(__FILE__)."/Plugin/$plugin_type/";
		my @plugin_files = glob($plugins_dir."*.pm");
		my @templates_ids = grep { $_ =~ s|$plugins_dir([\w\d]+)\.pm|$1| } @plugin_files;
		return \@templates_ids;
	}
	else {
	    return undef;
	}
##	else {
##		my $vendor = HSPC::MT::Core->find_account(
##			account_id => $h{vendor_id}
##		);
##		if ($vendor->type == &SW_RESELLER) {
##			my $reseller_config = HSPC::MT::CM::ResellerConfig->get_reseller_config(
##				vendor_id => $h{vendor_id},
##			);
##			my $templates = $reseller_config->get_available_plugins_list(plugin_type => $plugin_type);
##			return [map {$_->{plugin_id}} @$templates];
##		} else {
##			return undef;
##		}
##	}
}

## Description: checks, if plugin template is available to vendor, according to reseller configs policy
## Parameters:
##   vendor_id
##   template_id
##   plugin_type
## Returns: 1|0
sub is_template_available {
	my $class = shift;
	my %h = (
		vendor_id => undef,
		template_id => undef,
		plugin_type => undef,
		@_
	);
	
	return 1 if $h{vendor_id} == SW_HSP_ID;
	return 0;
	
##	my $vendor = HSPC::MT::Core->find_account(
##		account_id => $h{vendor_id}
##	);
	
##	if ($vendor->type == SW_RESELLER) {
##		## Get available plugins from reseller config
##		my $reseller_config = HSPC::MT::CM::ResellerConfig->get_reseller_config(
##			vendor_id => $h{vendor_id},
##		);
		
##		return $reseller_config->is_plugin_available(
##			plugin_id   => $h{template_id},
##			plugin_type => $h{plugin_type},
##		);
##	} else {
##		return 0;
##	}
}

## find plugin object
## (config + engine)
## return - plugin
## parameters:
## id - plugin id
## vendor_id - vendor of plugin
## force_permission - do not check template permissions
## force_activity  -  do not check activity
sub find_plugin {
	my $class = shift;
	my %h = (
		id                      => undef,
		plugin_type             => undef,
		vendor_id               => undef,
		force_permission        => undef,
		force_activity          => undef,
		force_template_existing => undef,
		@_
	);

	my $id                      = $h{id};
	my $force_activity          = $h{force_activity};
	my $force_permission        = $h{force_permission};
	my $plugin_type             = $h{plugin_type};
	my $vendor_id               = $h{vendor_id};
	my $force_template_existing = $h{force_template_existing};

	## throw HSPC::MT::AD::Exception(AD_ERR_INVALID_FNAME,MOD_AD) 
	##		unless $plugin_type || $id;

	if (!$plugin_type) {
		my $obj = $class->new();

		$obj->load( id => $id );
		
		## throw HSPC::MT::AD::Exception(AD_ERR_INVALID_FNAME,MOD_AD) 
		##		unless $vendor_id;

		if ($obj->vendor_id() != $vendor_id ) {
			return undef;
		}

		if (!$force_activity && !$obj->is_active) {
			return undef;
		}
		
		if (!$force_permission
			&& !$class->is_template_available(
							vendor_id   => $vendor_id,
							template_id => $obj->template_id,
							plugin_type => $obj->plugin_type,
						) 
		) {
			return undef;
		}

		if ( !$force_template_existing && !$obj->find_mt_template() ) {
			return undef;
		}

		$plugin_type = $obj->plugin_type;
	}
##	throw HSPC::MT::AD::Exception(AD_ERR_INVALID_FNAME,MOD_AD) 
##		unless $plugin_type;

	my $engine = "HSPC::MT:\:$plugin_type\::PluginEngine";

	eval "use $engine;";
##	throw HSPC::MT::AD::Exception(AD_ERR_INVALID_FNAME,MOD_AD) if $@;
	if (!$id) {
		return undef;
	}

	my $plugin = $engine->find( id => $id );

	if ( defined($plugin) ) {
		set_request_data('plugin_type', $plugin_type);
		return $plugin;
	} else {
		return undef;
	}
}

sub find_plugins {
	my $class = shift;
	my %h = (
		vendor_id        => undef,
		force_permission => undef,
		force_activity   => undef,
		plugin_type      => undef,
		request          => undef,
		@_
	);

	my $force_activity   = $h{force_activity};
	my $force_permission = $h{force_permission};
	my $vendor_id        = $h{vendor_id};
	my $request          = $h{request};

	throw_exception(
		type        => 'error',
		log_message => 'vendor_id is a mandatory parameter'
	) unless $vendor_id;

	unless ($request) {
		my $plugin_type      = $h{plugin_type};

		throw_exception(
			type        => 'error',
			log_message => 'plugin_type is a mandatory parameter'
		) unless $plugin_type;

		my $template_ids = $class->find_templates(
			plugin_type      => $plugin_type,
			vendor_id        => $vendor_id,
			force_permission => $force_permission,
		);

		$request = HSPC::DataRequest->new(
			cols => [
				{ code => 'id' },
				{ code => 'vendor_id',   for_where => 1, value => $vendor_id },
				{ code => 'plugin_type', for_where => 1, value => $plugin_type }
			],
			select_as_hashes => 1
		);

		$request->set_col(code => 'is_active', for_where => '=', value => 1) if !$force_activity;
		
		$request->set_col(
			code => 'template_id', for_where => 1, value => $template_ids
		) if ( $template_ids && scalar(@{$template_ids}) );
	}

	$class->load_data(
		request => $request,
	);

	my @plugins;
	foreach (@{$request->{data}}) {
		my $plugin = $class->find_plugin(
			vendor_id        => $vendor_id,
			force_permission => $force_permission,
			force_activity   => $force_activity,
			id               => $_->{id},
		);

		push (@plugins, $plugin) if ($plugin);
	}

	return scalar (@plugins) ? \@plugins : undef;
}

sub config_data {
	my $self = shift;

	my $config_data = shift;

	if ($config_data) {
		$self->{_config_data} = $config_data;
	}
	
	if (!$self->{_config_data} && $self->{config_data}) {
		$self->{_config_data} = thaw($self->{config_data});	
	}


	return $self->{_config_data};
}

sub save {
	my $self = shift;

	$self->is_active(0)
		unless defined ($self->is_active());
	
	if ( defined $self->{_config_data} ) {
		$self->{config_data} = freeze( $self->{_config_data} ) ;
	}

	my $res = $self->SUPER::save();

	return $res;
}

1;
