##
## Copyright (C) 2000-2004  SWsoft#
## All rights reserved.
##
## PleskDomaind management
##

package HSPC::PM::PluginEngine::OnlineAccount;

use strict;

use SWsoft::protect;
 
use HSPC::WebSystemLib;
use HSPC::Localization qw(:DEFAULT string string_lang);
use HSPC::WebPage;
use HSPC::DataRequest;

use HSPC::Logger qw(sw_atrace sw_die sw_log sw_log_warn);
use HSPC::Localization::Date qw(gmt_now date_now cmp_dates);
use HSPC::DataCheck;

use HSPC::Error;

use Error  qw(:try);
use HSPC::Exc::Fatal;

use HSPC::MT::PM::PluginEngine::OnlineAccount;
use HSPC::MT::GM::Constants qw(:card_pr_type);
use HSPC::MT::PP::Constants;

use HSPC::MT::Billing::Constants qw(:DEFAULT :setup);
use HSPC::MT::PM::Constants qw(SW_PM_STATUS_UNCHECKED SW_PM_STATUS_OK SW_PM_STATUS_TXT SW_PM_STATUS_DELETED);

use HSPC::Billing::Hash;

use HSPC::MT::GM::Constants qw(:card_pr_type);

use HSPC::PM::PluginEngine;
use vars qw{@ISA};
@ISA = qw{HSPC::PM::PluginEngine};

sub new {
	my $class = shift;
	my %h = (
		'session_args' => undef,
		@_,
	);

	sw_die(__PACKAGE__." : session args not defined")
		unless ( ref($h{'session_args'}) 
			&& UNIVERSAL::isa(ref($h{'session_args'}),'HSPC::PM::SessionArgs') );

	if ($h{'session_args'}) {
		$h{'session_args'}->screen_ids({
			list => '07.01',
			view => '07.02',
			edit => '07.03',
			add  => '07.04',
			edoc => '07.05',
			key  => '07.06',
		});

		$h{'session_args'}->bread_crumbs({
			1 => { title_id => 'commerce_director_uc', url => q{$ENV{CC_BASEURL}.'/site.cgi/em/dash'} },
			2 => { title_id => 'online_pmnts_uc', url => q{$ENV{CC_BASEURL}.'/site.cgi/cc/dash_cd_pm_op'} },
			3 => { title_id => 'cred_cards_uc',	url => q{$self->session_args->page->{'common_url'}} },

		});
	}

	return $class->SUPER::new(%h);
}


##-----------------------------------------------------------------------------
sub teaser_skey {
    my $self = shift;

	my $trace = sw_atrace();
	my $sargs = $self->session_args;

	unless ( $sargs->paymethod_obj && $sargs->paymethod_obj->id ) {
		sw_die(__PACKAGE__ . ": Paymethod object is undefined");
	}

	my $main_page = $sargs->page;
	if ( $sargs->draw_header() ) {
		$ENV{COMPREP}->node(edit => 1)->{title_hash}->{title} =
			string('cc_uc') . ' #' . $sargs->paymethod_obj->id;
		$main_page->title(pages => []);
	}
	$main_page->statuses();

	return $self->SUPER::teaser_skey();

}

##-----------------------------------------------------------------------------
sub teaser_edit_docs {
    my $self = shift;

	my $trace = sw_atrace();
	my $sargs = $self->session_args;
	$ENV{ COMPREP }->node(
		alias  => 'payment_methods_op_act_edit_docs',
		choose => 1,
	) if($ENV{COMPREP});

	unless ( $sargs->paymethod_obj && $sargs->paymethod_obj->id() ) {
		sw_die(__PACKAGE__ . ": Paymethod object is undefined");
	}

	my $main_page = $sargs->page;

	if ( $sargs->draw_header() ) {
		$main_page->title(pages => []);
	}
	$main_page->statuses();

	my $url_ext = "/act,pay_doc/pmethod_id," . $sargs->paymethod_obj->id;

	## draw account general settings edit screen
	$self->edit_docs(
		obj          => $sargs->paymethod_obj,
		page         => $main_page,
		is_admin     => $sargs->is_admin,
		act_url_ext  => $url_ext,
	);

	return undef;
}

##-----------------------------------------------------------------------------
sub build_path {
	my $self = shift;
	my %h = (
		step => undef,
		@_
	);

	my $trace = &sw_atrace("step => $h{step}");

	my $result_step = $self->SUPER::build_path();

	if ( $self->session_args->bread_crumbs->{$result_step} ) {
		$self->session_args->page->add_header_nav_path(
			path => {
				title_id => $self->session_args->bread_crumbs->{$result_step}->{title_id},
				url => eval($self->session_args->bread_crumbs->{$result_step}->{url})
			},
			force => 1
		);
	}

	if ( $h{step} && $self->session_args->bread_crumbs->{$h{step}} ) {
		$self->session_args->page->add_header_nav_path(
			path => {
				title_id => $self->session_args->bread_crumbs->{$h{step}}->{title_id},
				url => eval($self->session_args->bread_crumbs->{$h{step}}->{url})
			},
			force => 1
		);
	}

	$h{step} = ($h{step} ? $h{step} : $result_step);
	$h{step}++;

	$trace->add("Res = $h{step}");
	return $h{step};
}

sub popup_url {
	return undef if !$ENV{COMPREP};
	return $ENV{COMPREP}->link(
		alias=>"payment_methods_op_act_popup",{plugin_type=>'op'}
	);
}

sub __title_single_id {
	return 'cc_uc';
}

sub __title_plural_id {
	return 'cred_cards_uc';
}


1;

