## Copyright (C) 2006  SWsoft
## All rights reserved.
## Here should be placed non-MT toolkit functions for plug-ins
package HSPC::PluginHelper::Base;
use strict;

use SWsoft::protect;
use HSPC::WebSystemLib qw(sw_uriparam);
use HSPC::Logger qw(sw_die);

sub is_plugin_sc_id {
	my $class = shift;
	my %h = (
		sc_id => undef,
		@_
	);
	my $sc_id = $h{sc_id} || sw_die('The sc_id is a mandatory parameter');

	my %known_sc_id_re = (
		'^01.04.18.02.11$' => 'HSPC::PM::Office',
		'^01.04.29.01.' => 'HSPC::LM::PluginEngine',
	);

	my $result = 0;
	foreach my $re ( keys %known_sc_id_re ) {
		if ( $sc_id =~ /$re/ ) {
			$result = $known_sc_id_re{$re};
			last;
		}
	}
	return $result;
}

sub is_plugin_alias {
	my $class = shift;
	my %h = (
		alias => undef,
		@_
	);
	my $alias = $h{alias} || return undef;

	my %known_aliases_re = (
		'^payment_plugins_' => 1,
		'^payment_methods_' => 1,
		'^domain_plugin_tab_gen' => 1,
		'^domain_plugin_tab_plugin' => 1,
		'^domain_plugins_new' => 1,
		'^license_plugin'=>1,
	);

	my $result = 0;
	foreach my $re ( keys %known_aliases_re ) {
		if ( $alias =~ /$re/ ) {
			$result = 1;
			last;
		}
	}
	return $result;
}

sub get_help_url {
	my $this = shift;
	my %h = (
		devscreen_id => undef,
		@_
	);

	my $class;
	if ( $ENV{COMPREP} && $ENV{COMPREP}->node_alias ) {
		my $node = $ENV{COMPREP}->node;
		if ( $this->is_plugin_alias(alias => $node->{alias}) ) {
			$class = $node->{class};
		}
	} else {
		$class = $this->is_plugin_sc_id(sc_id => $h{devscreen_id});
	}

	my $url = undef;
	if ( $class ) {
		eval("use $class;");
		unless ($@) {
			eval { $url = $class->get_help_url() };
		}
	}

	return $url;
}

sub teaser_view {
	my $this = shift;

	my $template_type = uc(sw_uriparam('tt'));

	my $engine;
	if($template_type ne 'DM'){
		$engine = 'HSPC::' . $template_type . '::PluginEngine';
	} else {
		$engine = 'HSPC::MT::DM::RegEngine';
	}

	eval "use $engine;";
	my $help = undef;
	unless ($@) {
		eval {
			$help = $engine->get_help_page(
				action        => sw_uriparam('a'),
				template_id   => sw_uriparam('ti'),
				language      => sw_uriparam('l'),
				sub_type      => sw_uriparam('st'),
				vendor_id     => sw_uriparam('vi'),
				customer_view => sw_uriparam('c'),
				plugin_id     => sw_uriparam('pi')
			);
			$help = $engine->get_help_page(
				action        => sw_uriparam('a'),
				template_id   => sw_uriparam('ti'),
				language      => 'en',
				sub_type      => sw_uriparam('st'),
				vendor_id     => sw_uriparam('vi'),
				customer_view => sw_uriparam('c'),
				plugin_id     => sw_uriparam('pi')
			) if(!$help);
		};
	}

	return { 
		'STATUS' => $help ? 'OK' : 'ERROR',
		'CONTENT' => $help,
	};
}

sub get_tooltip {
	my $this = shift;
	my %h = (
		devscreen_id => undef,
		@_
	);

	my $class;
	if ( $ENV{COMPREP} && $ENV{COMPREP}->node_alias ) {
		my $node = $ENV{COMPREP}->node;
		if ( $this->is_plugin_alias(alias => $node->{alias}) ) {
			$class = $node->{class};
		}
	} else {
		$class = $this->is_plugin_sc_id(sc_id => $h{devscreen_id});
	}

	my $tooltip = undef;
	if ( $class ) {
		eval("use $class;");
		unless ($@) {
			eval { $tooltip = $class->get_tooltip() };
		}
	}

	return $tooltip;
}

1;
